@@ -3,9 +3,11 @@ Main interface for mediapackage service type definitions.
 
 Usage::
 
-    from mypy_boto3.mediapackage.type_defs import AuthorizationTypeDef
+    ```python
+    from mypy_boto3_mediapackage.type_defs import AuthorizationTypeDef
 
     data: AuthorizationTypeDef = {...}
+    ```
 """
 import sys
 from typing import Dict, List
@@ -14,6 +16,7 @@ if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -22,33 +25,33 @@ else:
 
 __all__ = (
     "AuthorizationTypeDef",
-    "SpekeKeyProviderTypeDef",
+    "ChannelTypeDef",
     "CmafEncryptionTypeDef",
-    "HlsManifestCreateOrUpdateParametersTypeDef",
-    "StreamSelectionTypeDef",
-    "CmafPackageCreateOrUpdateParametersTypeDef",
-    "IngestEndpointTypeDef",
-    "HlsIngestTypeDef",
-    "CreateChannelResponseTypeDef",
-    "S3DestinationTypeDef",
-    "CreateHarvestJobResponseTypeDef",
-    "HlsManifestTypeDef",
     "CmafPackageTypeDef",
     "DashEncryptionTypeDef",
     "DashPackageTypeDef",
+    "HarvestJobTypeDef",
     "HlsEncryptionTypeDef",
+    "HlsIngestTypeDef",
+    "HlsManifestCreateOrUpdateParametersTypeDef",
+    "HlsManifestTypeDef",
     "HlsPackageTypeDef",
+    "IngestEndpointTypeDef",
     "MssEncryptionTypeDef",
     "MssPackageTypeDef",
+    "OriginEndpointTypeDef",
+    "S3DestinationTypeDef",
+    "SpekeKeyProviderTypeDef",
+    "StreamSelectionTypeDef",
+    "CmafPackageCreateOrUpdateParametersTypeDef",
+    "CreateChannelResponseTypeDef",
+    "CreateHarvestJobResponseTypeDef",
     "CreateOriginEndpointResponseTypeDef",
     "DescribeChannelResponseTypeDef",
     "DescribeHarvestJobResponseTypeDef",
     "DescribeOriginEndpointResponseTypeDef",
-    "ChannelTypeDef",
     "ListChannelsResponseTypeDef",
-    "HarvestJobTypeDef",
     "ListHarvestJobsResponseTypeDef",
-    "OriginEndpointTypeDef",
     "ListOriginEndpointsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
@@ -62,21 +65,20 @@ AuthorizationTypeDef = TypedDict(
     "AuthorizationTypeDef", {"CdnIdentifierSecret": str, "SecretsRoleArn": str}
 )
 
-_RequiredSpekeKeyProviderTypeDef = TypedDict(
-    "_RequiredSpekeKeyProviderTypeDef",
-    {"ResourceId": str, "RoleArn": str, "SystemIds": List[str], "Url": str},
+ChannelTypeDef = TypedDict(
+    "ChannelTypeDef",
+    {
+        "Arn": str,
+        "Description": str,
+        "HlsIngest": "HlsIngestTypeDef",
+        "Id": str,
+        "Tags": Dict[str, str],
+    },
+    total=False,
 )
-_OptionalSpekeKeyProviderTypeDef = TypedDict(
-    "_OptionalSpekeKeyProviderTypeDef", {"CertificateArn": str}, total=False
-)
-
-
-class SpekeKeyProviderTypeDef(_RequiredSpekeKeyProviderTypeDef, _OptionalSpekeKeyProviderTypeDef):
-    pass
-
 
 _RequiredCmafEncryptionTypeDef = TypedDict(
-    "_RequiredCmafEncryptionTypeDef", {"SpekeKeyProvider": SpekeKeyProviderTypeDef}
+    "_RequiredCmafEncryptionTypeDef", {"SpekeKeyProvider": "SpekeKeyProviderTypeDef"}
 )
 _OptionalCmafEncryptionTypeDef = TypedDict(
     "_OptionalCmafEncryptionTypeDef", {"KeyRotationIntervalSeconds": int}, total=False
@@ -87,13 +89,109 @@ class CmafEncryptionTypeDef(_RequiredCmafEncryptionTypeDef, _OptionalCmafEncrypt
     pass
 
 
+CmafPackageTypeDef = TypedDict(
+    "CmafPackageTypeDef",
+    {
+        "Encryption": "CmafEncryptionTypeDef",
+        "HlsManifests": List["HlsManifestTypeDef"],
+        "SegmentDurationSeconds": int,
+        "SegmentPrefix": str,
+        "StreamSelection": "StreamSelectionTypeDef",
+    },
+    total=False,
+)
+
+_RequiredDashEncryptionTypeDef = TypedDict(
+    "_RequiredDashEncryptionTypeDef", {"SpekeKeyProvider": "SpekeKeyProviderTypeDef"}
+)
+_OptionalDashEncryptionTypeDef = TypedDict(
+    "_OptionalDashEncryptionTypeDef", {"KeyRotationIntervalSeconds": int}, total=False
+)
+
+
+class DashEncryptionTypeDef(_RequiredDashEncryptionTypeDef, _OptionalDashEncryptionTypeDef):
+    pass
+
+
+DashPackageTypeDef = TypedDict(
+    "DashPackageTypeDef",
+    {
+        "AdTriggers": List[
+            Literal[
+                "SPLICE_INSERT",
+                "BREAK",
+                "PROVIDER_ADVERTISEMENT",
+                "DISTRIBUTOR_ADVERTISEMENT",
+                "PROVIDER_PLACEMENT_OPPORTUNITY",
+                "DISTRIBUTOR_PLACEMENT_OPPORTUNITY",
+                "PROVIDER_OVERLAY_PLACEMENT_OPPORTUNITY",
+                "DISTRIBUTOR_OVERLAY_PLACEMENT_OPPORTUNITY",
+            ]
+        ],
+        "AdsOnDeliveryRestrictions": Literal["NONE", "RESTRICTED", "UNRESTRICTED", "BOTH"],
+        "Encryption": "DashEncryptionTypeDef",
+        "ManifestLayout": Literal["FULL", "COMPACT"],
+        "ManifestWindowSeconds": int,
+        "MinBufferTimeSeconds": int,
+        "MinUpdatePeriodSeconds": int,
+        "PeriodTriggers": List[Literal["ADS"]],
+        "Profile": Literal["NONE", "HBBTV_1_5"],
+        "SegmentDurationSeconds": int,
+        "SegmentTemplateFormat": Literal[
+            "NUMBER_WITH_TIMELINE", "TIME_WITH_TIMELINE", "NUMBER_WITH_DURATION"
+        ],
+        "StreamSelection": "StreamSelectionTypeDef",
+        "SuggestedPresentationDelaySeconds": int,
+    },
+    total=False,
+)
+
+HarvestJobTypeDef = TypedDict(
+    "HarvestJobTypeDef",
+    {
+        "Arn": str,
+        "ChannelId": str,
+        "CreatedAt": str,
+        "EndTime": str,
+        "Id": str,
+        "OriginEndpointId": str,
+        "S3Destination": "S3DestinationTypeDef",
+        "StartTime": str,
+        "Status": Literal["IN_PROGRESS", "SUCCEEDED", "FAILED"],
+    },
+    total=False,
+)
+
+_RequiredHlsEncryptionTypeDef = TypedDict(
+    "_RequiredHlsEncryptionTypeDef", {"SpekeKeyProvider": "SpekeKeyProviderTypeDef"}
+)
+_OptionalHlsEncryptionTypeDef = TypedDict(
+    "_OptionalHlsEncryptionTypeDef",
+    {
+        "ConstantInitializationVector": str,
+        "EncryptionMethod": Literal["AES_128", "SAMPLE_AES"],
+        "KeyRotationIntervalSeconds": int,
+        "RepeatExtXKey": bool,
+    },
+    total=False,
+)
+
+
+class HlsEncryptionTypeDef(_RequiredHlsEncryptionTypeDef, _OptionalHlsEncryptionTypeDef):
+    pass
+
+
+HlsIngestTypeDef = TypedDict(
+    "HlsIngestTypeDef", {"IngestEndpoints": List["IngestEndpointTypeDef"]}, total=False
+)
+
 _RequiredHlsManifestCreateOrUpdateParametersTypeDef = TypedDict(
     "_RequiredHlsManifestCreateOrUpdateParametersTypeDef", {"Id": str}
 )
 _OptionalHlsManifestCreateOrUpdateParametersTypeDef = TypedDict(
     "_OptionalHlsManifestCreateOrUpdateParametersTypeDef",
     {
-        "AdMarkers": Literal["NONE", "SCTE35_ENHANCED", "PASSTHROUGH"],
+        "AdMarkers": Literal["NONE", "SCTE35_ENHANCED", "PASSTHROUGH", "DATERANGE"],
         "AdTriggers": List[
             Literal[
                 "SPLICE_INSERT",
@@ -124,73 +222,11 @@ class HlsManifestCreateOrUpdateParametersTypeDef(
     pass
 
 
-StreamSelectionTypeDef = TypedDict(
-    "StreamSelectionTypeDef",
-    {
-        "MaxVideoBitsPerSecond": int,
-        "MinVideoBitsPerSecond": int,
-        "StreamOrder": Literal["ORIGINAL", "VIDEO_BITRATE_ASCENDING", "VIDEO_BITRATE_DESCENDING"],
-    },
-    total=False,
-)
-
-CmafPackageCreateOrUpdateParametersTypeDef = TypedDict(
-    "CmafPackageCreateOrUpdateParametersTypeDef",
-    {
-        "Encryption": CmafEncryptionTypeDef,
-        "HlsManifests": List[HlsManifestCreateOrUpdateParametersTypeDef],
-        "SegmentDurationSeconds": int,
-        "SegmentPrefix": str,
-        "StreamSelection": StreamSelectionTypeDef,
-    },
-    total=False,
-)
-
-IngestEndpointTypeDef = TypedDict(
-    "IngestEndpointTypeDef", {"Id": str, "Password": str, "Url": str, "Username": str}, total=False
-)
-
-HlsIngestTypeDef = TypedDict(
-    "HlsIngestTypeDef", {"IngestEndpoints": List[IngestEndpointTypeDef]}, total=False
-)
-
-CreateChannelResponseTypeDef = TypedDict(
-    "CreateChannelResponseTypeDef",
-    {
-        "Arn": str,
-        "Description": str,
-        "HlsIngest": HlsIngestTypeDef,
-        "Id": str,
-        "Tags": Dict[str, str],
-    },
-    total=False,
-)
-
-S3DestinationTypeDef = TypedDict(
-    "S3DestinationTypeDef", {"BucketName": str, "ManifestKey": str, "RoleArn": str}
-)
-
-CreateHarvestJobResponseTypeDef = TypedDict(
-    "CreateHarvestJobResponseTypeDef",
-    {
-        "Arn": str,
-        "ChannelId": str,
-        "CreatedAt": str,
-        "EndTime": str,
-        "Id": str,
-        "OriginEndpointId": str,
-        "S3Destination": S3DestinationTypeDef,
-        "StartTime": str,
-        "Status": Literal["IN_PROGRESS", "SUCCEEDED", "FAILED"],
-    },
-    total=False,
-)
-
 _RequiredHlsManifestTypeDef = TypedDict("_RequiredHlsManifestTypeDef", {"Id": str})
 _OptionalHlsManifestTypeDef = TypedDict(
     "_OptionalHlsManifestTypeDef",
     {
-        "AdMarkers": Literal["NONE", "SCTE35_ENHANCED", "PASSTHROUGH"],
+        "AdMarkers": Literal["NONE", "SCTE35_ENHANCED", "PASSTHROUGH", "DATERANGE"],
         "IncludeIframeOnlyStream": bool,
         "ManifestName": str,
         "PlaylistType": Literal["NONE", "EVENT", "VOD"],
@@ -206,86 +242,10 @@ class HlsManifestTypeDef(_RequiredHlsManifestTypeDef, _OptionalHlsManifestTypeDe
     pass
 
 
-CmafPackageTypeDef = TypedDict(
-    "CmafPackageTypeDef",
-    {
-        "Encryption": CmafEncryptionTypeDef,
-        "HlsManifests": List[HlsManifestTypeDef],
-        "SegmentDurationSeconds": int,
-        "SegmentPrefix": str,
-        "StreamSelection": StreamSelectionTypeDef,
-    },
-    total=False,
-)
-
-_RequiredDashEncryptionTypeDef = TypedDict(
-    "_RequiredDashEncryptionTypeDef", {"SpekeKeyProvider": SpekeKeyProviderTypeDef}
-)
-_OptionalDashEncryptionTypeDef = TypedDict(
-    "_OptionalDashEncryptionTypeDef", {"KeyRotationIntervalSeconds": int}, total=False
-)
-
-
-class DashEncryptionTypeDef(_RequiredDashEncryptionTypeDef, _OptionalDashEncryptionTypeDef):
-    pass
-
-
-DashPackageTypeDef = TypedDict(
-    "DashPackageTypeDef",
-    {
-        "AdTriggers": List[
-            Literal[
-                "SPLICE_INSERT",
-                "BREAK",
-                "PROVIDER_ADVERTISEMENT",
-                "DISTRIBUTOR_ADVERTISEMENT",
-                "PROVIDER_PLACEMENT_OPPORTUNITY",
-                "DISTRIBUTOR_PLACEMENT_OPPORTUNITY",
-                "PROVIDER_OVERLAY_PLACEMENT_OPPORTUNITY",
-                "DISTRIBUTOR_OVERLAY_PLACEMENT_OPPORTUNITY",
-            ]
-        ],
-        "AdsOnDeliveryRestrictions": Literal["NONE", "RESTRICTED", "UNRESTRICTED", "BOTH"],
-        "Encryption": DashEncryptionTypeDef,
-        "ManifestLayout": Literal["FULL", "COMPACT"],
-        "ManifestWindowSeconds": int,
-        "MinBufferTimeSeconds": int,
-        "MinUpdatePeriodSeconds": int,
-        "PeriodTriggers": List[Literal["ADS"]],
-        "Profile": Literal["NONE", "HBBTV_1_5"],
-        "SegmentDurationSeconds": int,
-        "SegmentTemplateFormat": Literal[
-            "NUMBER_WITH_TIMELINE", "TIME_WITH_TIMELINE", "NUMBER_WITH_DURATION"
-        ],
-        "StreamSelection": StreamSelectionTypeDef,
-        "SuggestedPresentationDelaySeconds": int,
-    },
-    total=False,
-)
-
-_RequiredHlsEncryptionTypeDef = TypedDict(
-    "_RequiredHlsEncryptionTypeDef", {"SpekeKeyProvider": SpekeKeyProviderTypeDef}
-)
-_OptionalHlsEncryptionTypeDef = TypedDict(
-    "_OptionalHlsEncryptionTypeDef",
-    {
-        "ConstantInitializationVector": str,
-        "EncryptionMethod": Literal["AES_128", "SAMPLE_AES"],
-        "KeyRotationIntervalSeconds": int,
-        "RepeatExtXKey": bool,
-    },
-    total=False,
-)
-
-
-class HlsEncryptionTypeDef(_RequiredHlsEncryptionTypeDef, _OptionalHlsEncryptionTypeDef):
-    pass
-
-
 HlsPackageTypeDef = TypedDict(
     "HlsPackageTypeDef",
     {
-        "AdMarkers": Literal["NONE", "SCTE35_ENHANCED", "PASSTHROUGH"],
+        "AdMarkers": Literal["NONE", "SCTE35_ENHANCED", "PASSTHROUGH", "DATERANGE"],
         "AdTriggers": List[
             Literal[
                 "SPLICE_INSERT",
@@ -299,29 +259,123 @@ HlsPackageTypeDef = TypedDict(
             ]
         ],
         "AdsOnDeliveryRestrictions": Literal["NONE", "RESTRICTED", "UNRESTRICTED", "BOTH"],
-        "Encryption": HlsEncryptionTypeDef,
+        "Encryption": "HlsEncryptionTypeDef",
         "IncludeIframeOnlyStream": bool,
         "PlaylistType": Literal["NONE", "EVENT", "VOD"],
         "PlaylistWindowSeconds": int,
         "ProgramDateTimeIntervalSeconds": int,
         "SegmentDurationSeconds": int,
-        "StreamSelection": StreamSelectionTypeDef,
+        "StreamSelection": "StreamSelectionTypeDef",
         "UseAudioRenditionGroup": bool,
     },
     total=False,
 )
 
+IngestEndpointTypeDef = TypedDict(
+    "IngestEndpointTypeDef", {"Id": str, "Password": str, "Url": str, "Username": str}, total=False
+)
+
 MssEncryptionTypeDef = TypedDict(
-    "MssEncryptionTypeDef", {"SpekeKeyProvider": SpekeKeyProviderTypeDef}
+    "MssEncryptionTypeDef", {"SpekeKeyProvider": "SpekeKeyProviderTypeDef"}
 )
 
 MssPackageTypeDef = TypedDict(
     "MssPackageTypeDef",
     {
-        "Encryption": MssEncryptionTypeDef,
+        "Encryption": "MssEncryptionTypeDef",
         "ManifestWindowSeconds": int,
         "SegmentDurationSeconds": int,
-        "StreamSelection": StreamSelectionTypeDef,
+        "StreamSelection": "StreamSelectionTypeDef",
+    },
+    total=False,
+)
+
+OriginEndpointTypeDef = TypedDict(
+    "OriginEndpointTypeDef",
+    {
+        "Arn": str,
+        "Authorization": "AuthorizationTypeDef",
+        "ChannelId": str,
+        "CmafPackage": "CmafPackageTypeDef",
+        "DashPackage": "DashPackageTypeDef",
+        "Description": str,
+        "HlsPackage": "HlsPackageTypeDef",
+        "Id": str,
+        "ManifestName": str,
+        "MssPackage": "MssPackageTypeDef",
+        "Origination": Literal["ALLOW", "DENY"],
+        "StartoverWindowSeconds": int,
+        "Tags": Dict[str, str],
+        "TimeDelaySeconds": int,
+        "Url": str,
+        "Whitelist": List[str],
+    },
+    total=False,
+)
+
+S3DestinationTypeDef = TypedDict(
+    "S3DestinationTypeDef", {"BucketName": str, "ManifestKey": str, "RoleArn": str}
+)
+
+_RequiredSpekeKeyProviderTypeDef = TypedDict(
+    "_RequiredSpekeKeyProviderTypeDef",
+    {"ResourceId": str, "RoleArn": str, "SystemIds": List[str], "Url": str},
+)
+_OptionalSpekeKeyProviderTypeDef = TypedDict(
+    "_OptionalSpekeKeyProviderTypeDef", {"CertificateArn": str}, total=False
+)
+
+
+class SpekeKeyProviderTypeDef(_RequiredSpekeKeyProviderTypeDef, _OptionalSpekeKeyProviderTypeDef):
+    pass
+
+
+StreamSelectionTypeDef = TypedDict(
+    "StreamSelectionTypeDef",
+    {
+        "MaxVideoBitsPerSecond": int,
+        "MinVideoBitsPerSecond": int,
+        "StreamOrder": Literal["ORIGINAL", "VIDEO_BITRATE_ASCENDING", "VIDEO_BITRATE_DESCENDING"],
+    },
+    total=False,
+)
+
+CmafPackageCreateOrUpdateParametersTypeDef = TypedDict(
+    "CmafPackageCreateOrUpdateParametersTypeDef",
+    {
+        "Encryption": "CmafEncryptionTypeDef",
+        "HlsManifests": List["HlsManifestCreateOrUpdateParametersTypeDef"],
+        "SegmentDurationSeconds": int,
+        "SegmentPrefix": str,
+        "StreamSelection": "StreamSelectionTypeDef",
+    },
+    total=False,
+)
+
+CreateChannelResponseTypeDef = TypedDict(
+    "CreateChannelResponseTypeDef",
+    {
+        "Arn": str,
+        "Description": str,
+        "HlsIngest": "HlsIngestTypeDef",
+        "Id": str,
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+CreateHarvestJobResponseTypeDef = TypedDict(
+    "CreateHarvestJobResponseTypeDef",
+    {
+        "Arn": str,
+        "ChannelId": str,
+        "CreatedAt": str,
+        "EndTime": str,
+        "Id": str,
+        "OriginEndpointId": str,
+        "S3Destination": "S3DestinationTypeDef",
+        "StartTime": str,
+        "Status": Literal["IN_PROGRESS", "SUCCEEDED", "FAILED"],
     },
     total=False,
 )
@@ -330,15 +384,15 @@ CreateOriginEndpointResponseTypeDef = TypedDict(
     "CreateOriginEndpointResponseTypeDef",
     {
         "Arn": str,
-        "Authorization": AuthorizationTypeDef,
+        "Authorization": "AuthorizationTypeDef",
         "ChannelId": str,
-        "CmafPackage": CmafPackageTypeDef,
-        "DashPackage": DashPackageTypeDef,
+        "CmafPackage": "CmafPackageTypeDef",
+        "DashPackage": "DashPackageTypeDef",
         "Description": str,
-        "HlsPackage": HlsPackageTypeDef,
+        "HlsPackage": "HlsPackageTypeDef",
         "Id": str,
         "ManifestName": str,
-        "MssPackage": MssPackageTypeDef,
+        "MssPackage": "MssPackageTypeDef",
         "Origination": Literal["ALLOW", "DENY"],
         "StartoverWindowSeconds": int,
         "Tags": Dict[str, str],
@@ -354,7 +408,7 @@ DescribeChannelResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "Description": str,
-        "HlsIngest": HlsIngestTypeDef,
+        "HlsIngest": "HlsIngestTypeDef",
         "Id": str,
         "Tags": Dict[str, str],
     },
@@ -370,7 +424,7 @@ DescribeHarvestJobResponseTypeDef = TypedDict(
         "EndTime": str,
         "Id": str,
         "OriginEndpointId": str,
-        "S3Destination": S3DestinationTypeDef,
+        "S3Destination": "S3DestinationTypeDef",
         "StartTime": str,
         "Status": Literal["IN_PROGRESS", "SUCCEEDED", "FAILED"],
     },
@@ -381,15 +435,15 @@ DescribeOriginEndpointResponseTypeDef = TypedDict(
     "DescribeOriginEndpointResponseTypeDef",
     {
         "Arn": str,
-        "Authorization": AuthorizationTypeDef,
+        "Authorization": "AuthorizationTypeDef",
         "ChannelId": str,
-        "CmafPackage": CmafPackageTypeDef,
-        "DashPackage": DashPackageTypeDef,
+        "CmafPackage": "CmafPackageTypeDef",
+        "DashPackage": "DashPackageTypeDef",
         "Description": str,
-        "HlsPackage": HlsPackageTypeDef,
+        "HlsPackage": "HlsPackageTypeDef",
         "Id": str,
         "ManifestName": str,
-        "MssPackage": MssPackageTypeDef,
+        "MssPackage": "MssPackageTypeDef",
         "Origination": Literal["ALLOW", "DENY"],
         "StartoverWindowSeconds": int,
         "Tags": Dict[str, str],
@@ -400,70 +454,21 @@ DescribeOriginEndpointResponseTypeDef = TypedDict(
     total=False,
 )
 
-ChannelTypeDef = TypedDict(
-    "ChannelTypeDef",
-    {
-        "Arn": str,
-        "Description": str,
-        "HlsIngest": HlsIngestTypeDef,
-        "Id": str,
-        "Tags": Dict[str, str],
-    },
-    total=False,
-)
-
 ListChannelsResponseTypeDef = TypedDict(
-    "ListChannelsResponseTypeDef", {"Channels": List[ChannelTypeDef], "NextToken": str}, total=False
-)
-
-HarvestJobTypeDef = TypedDict(
-    "HarvestJobTypeDef",
-    {
-        "Arn": str,
-        "ChannelId": str,
-        "CreatedAt": str,
-        "EndTime": str,
-        "Id": str,
-        "OriginEndpointId": str,
-        "S3Destination": S3DestinationTypeDef,
-        "StartTime": str,
-        "Status": Literal["IN_PROGRESS", "SUCCEEDED", "FAILED"],
-    },
+    "ListChannelsResponseTypeDef",
+    {"Channels": List["ChannelTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListHarvestJobsResponseTypeDef = TypedDict(
     "ListHarvestJobsResponseTypeDef",
-    {"HarvestJobs": List[HarvestJobTypeDef], "NextToken": str},
-    total=False,
-)
-
-OriginEndpointTypeDef = TypedDict(
-    "OriginEndpointTypeDef",
-    {
-        "Arn": str,
-        "Authorization": AuthorizationTypeDef,
-        "ChannelId": str,
-        "CmafPackage": CmafPackageTypeDef,
-        "DashPackage": DashPackageTypeDef,
-        "Description": str,
-        "HlsPackage": HlsPackageTypeDef,
-        "Id": str,
-        "ManifestName": str,
-        "MssPackage": MssPackageTypeDef,
-        "Origination": Literal["ALLOW", "DENY"],
-        "StartoverWindowSeconds": int,
-        "Tags": Dict[str, str],
-        "TimeDelaySeconds": int,
-        "Url": str,
-        "Whitelist": List[str],
-    },
+    {"HarvestJobs": List["HarvestJobTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListOriginEndpointsResponseTypeDef = TypedDict(
     "ListOriginEndpointsResponseTypeDef",
-    {"NextToken": str, "OriginEndpoints": List[OriginEndpointTypeDef]},
+    {"NextToken": str, "OriginEndpoints": List["OriginEndpointTypeDef"]},
     total=False,
 )
 
@@ -480,7 +485,7 @@ RotateChannelCredentialsResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "Description": str,
-        "HlsIngest": HlsIngestTypeDef,
+        "HlsIngest": "HlsIngestTypeDef",
         "Id": str,
         "Tags": Dict[str, str],
     },
@@ -492,7 +497,7 @@ RotateIngestEndpointCredentialsResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "Description": str,
-        "HlsIngest": HlsIngestTypeDef,
+        "HlsIngest": "HlsIngestTypeDef",
         "Id": str,
         "Tags": Dict[str, str],
     },
@@ -504,7 +509,7 @@ UpdateChannelResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "Description": str,
-        "HlsIngest": HlsIngestTypeDef,
+        "HlsIngest": "HlsIngestTypeDef",
         "Id": str,
         "Tags": Dict[str, str],
     },
@@ -515,15 +520,15 @@ UpdateOriginEndpointResponseTypeDef = TypedDict(
     "UpdateOriginEndpointResponseTypeDef",
     {
         "Arn": str,
-        "Authorization": AuthorizationTypeDef,
+        "Authorization": "AuthorizationTypeDef",
         "ChannelId": str,
-        "CmafPackage": CmafPackageTypeDef,
-        "DashPackage": DashPackageTypeDef,
+        "CmafPackage": "CmafPackageTypeDef",
+        "DashPackage": "DashPackageTypeDef",
         "Description": str,
-        "HlsPackage": HlsPackageTypeDef,
+        "HlsPackage": "HlsPackageTypeDef",
         "Id": str,
         "ManifestName": str,
-        "MssPackage": MssPackageTypeDef,
+        "MssPackage": "MssPackageTypeDef",
         "Origination": Literal["ALLOW", "DENY"],
         "StartoverWindowSeconds": int,
         "Tags": Dict[str, str],
